<?php

/**
 * @file
 * Contains DailyEventHandler.
 */

namespace Drupal\rules_repeated_events\Plugin\Rules\Event;

/**
 * Event handler for tweets on the personal timeline.
 */
class DailyEventHandler extends RepeatedEventHandlerBase {

  /**
   * Defines the event.
   */
  public static function getInfo() {
    return static::getInfoDefaults() + array(
      'name' => 'daily_events',
      'label' => t('Daily Events.'),
      'variables' => array(),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getTaskHandler() {
    return 'Drupal\rules_repeated_events\TaskHandler\DailyEventsTaskHandler';
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaults() {
    return array(
      'time' => '12:00am',
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array &$form_state) {
    $settings = $this->getSettings();

    $form['time'] = array(
      '#type' => 'jquery_timepicker',
      '#title' => t('Time'),
      '#description' => t('The time to do action daily.'),
      '#default_value' => $settings['time'],
      '#required' => TRUE,
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    $settings = $this->getSettings();
    if ($settings['time']) {
      return t('Actions will be triggered every day on %time.', array('%time' => $settings['time']));
    }
    return $this->eventInfo['label'];
  }

  /**
   * {@inheritdoc}
   */
  public function startWatching() {
    // Scheduled time in local timezone.
    $settings = $this->getSettings();
    $scheduledTimeStamp = strtotime($settings['time']);
    // Convert it to server timezone.
    $diff = rules_repeated_events_get_local_server_timestamp_diff();
    $scheduledTimeStamp = $scheduledTimeStamp - $diff;

    // Current time in server timezone.
    $currentTime = time();

    // Find the first scheduled time.
    if ($scheduledTimeStamp < $currentTime) {
      // It is late, will trigger on next day.
      $scheduledTimeStamp = strtotime('+1 day', $scheduledTimeStamp);
    }

    rules_scheduler_schedule_task(array(
      'date' => $scheduledTimeStamp,
      'identifier' => "{$this->getEventName()}--{$this->getEventNameSuffix()}",
      'config' => '',
      'data' => $this->getSettings(),
      'handler' => $this->getTaskHandler(),
    ));
  }

}
